How to contribute
=================

Add more adjectives and nouns
-----------------------------

The more, the better - as long as names are cool!

Feel free to open a pull request for ``coolname/data`` files.
Or just send me an email with your suggestions.

If you find some words too sophisticated / not so cool / just plain wrong,
please let me know. English is my not native language, and I may have some
wrong ideas about words meaning and usage.

Report bugs
-----------

Report bugs at https://github.com/alexanderlukanin13/coolname/issues.

If you are reporting a bug, please include:

* Your operating system name and version.
* Python version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the bug.

Add new features
----------------

If you want to extend API, please create a feature request at
https://github.com/alexanderlukanin13/coolname/issues

Pull request guidelines
-----------------------

Before you submit a pull request, check that it meets these guidelines:

1. The pull request should include tests.
2. New functions/methods should be reasonably documented.
3. The pull request should pass all CI tests.
